==> model-1.2-sources.jar: org/ow2/weblab/core/model/StringQuery.java <==

package org.ow2.weblab.core.model;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * This query is dedicated for any query
 * 				expression language which can be expressed in a simple string such
 * 				as full text queries, XQuery or SPARQL. Details on the language used
 * 				to express the query should be provided in an Annotation on the
 * 				query. Data Exchange Model for WebLab platform provided by CASSIDIAN -
 * 				Version 1.2 - 2010/08
 * 
 * <p>Java class for StringQuery complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StringQuery">
 *   &lt;complexContent>
 *     &lt;extension base="{http://weblab.ow2.org/core/1.2/model#}ElementaryQuery">
 *       &lt;sequence>
 *         &lt;element name="request" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StringQuery", propOrder = {
    "request"
})
public class StringQuery
    extends ElementaryQuery
    implements Serializable
{

    private final static long serialVersionUID = 12L;
    @XmlElement(required = true)
    protected String request;

    /**
     * Gets the value of the request property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRequest() {
        return request;
    }

    /**
     * Sets the value of the request property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRequest(String value) {
        this.request = value;
    }

}

==> model-1.2.2-sources.jar: org/ow2/weblab/core/model/StringQuery.java <==

package org.ow2.weblab.core.model;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * This Query is dedicated for any Query expression language which can be expressed in a simple string such as full text queries, 
 *             XQuery or SPARQL. Details on the language used to express the Query should be provided in an Annotation on the Query.
 * 
 * 
 * 				Data Exchange Model for WebLab platform provided by CASSIDIAN Version 1.2.1 - 2011/05
 * 
 * <p>Java class for StringQuery complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StringQuery">
 *   &lt;complexContent>
 *     &lt;extension base="{http://weblab.ow2.org/core/1.2/model#}ElementaryQuery">
 *       &lt;sequence>
 *         &lt;element name="request" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StringQuery", propOrder = {
    "request"
})
public class StringQuery
    extends ElementaryQuery
    implements Serializable
{

    private final static long serialVersionUID = 121L;
    @XmlElement(required = true)
    protected String request;

    /**
     * Gets the value of the request property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRequest() {
        return request;
    }

    /**
     * Sets the value of the request property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRequest(String value) {
        this.request = value;
    }

}
